var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target, mod));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/validation.ts
var validation_exports = {};
__export(validation_exports, {
  ParseBody: () => ParseBody,
  ValidateBody: () => ValidateBody,
  permits: () => permits,
  requires: () => requires
});
module.exports = __toCommonJS(validation_exports);
var import_ajv = __toESM(require("ajv"));
var import_lodash = __toESM(require("lodash"));
var import_hypernight = require("@hyperstackjs/hypernight");

// src/errors.ts
var ValidationError = class extends Error {
  constructor(errors) {
    super();
    this.errors = errors;
    this.isValidationError = true;
    Object.setPrototypeOf(this, ValidationError.prototype);
  }
};

// src/validation.ts
var permits = (schema) => schema.parse.bind(schema);
var requires = (schema) => {
  const s = schema.strict();
  return (d) => {
    const result = s.safeParse(d);
    if (!result.success) {
      throw new ValidationError(result.error.issues);
    }
    return result.data;
  };
};
function ParseBody(schema) {
  function parseBody(req, res, next) {
    const { success, data, error } = schema.safeParse(req.body);
    if (!success) {
      throw new ValidationError(error.issues);
    } else {
      req.body = data;
    }
    next();
  }
  parseBody.params = { schema: { zod: schema } };
  return (0, import_hypernight.Middleware)(parseBody);
}
function ValidateBody(schema, customValidations = {}) {
  const ajv = new import_ajv.default();
  import_lodash.default.toPairs(customValidations).forEach(([validationName, validationSchema]) => {
    ajv.addKeyword(validationName, validationSchema);
  });
  function validateBody(req, res, next) {
    const validator = ajv.compile(schema);
    if (!validator(req.body)) {
      throw new ValidationError(validator.errors);
    }
    next();
  }
  return (0, import_hypernight.Middleware)(validateBody);
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  ParseBody,
  ValidateBody,
  permits,
  requires
});
